require 'thor'
require 'norad_serverspec_runner/task'
require 'base64'
require 'openssl'

module NoradServerspecRunner
  # Drives the CLI for norad_serverspec_runner
  class Cli < Thor
    desc 'remote encoded_key', 'Will test a server using serverspec'
    long_desc <<-SPEC_REMOTE

    `norad_serverspec_runner remote` will ssh into a server and run serverspec tests
    SPEC_REMOTE
    method_option :host, :aliases => '-h', :desc => 'Host to scan'
    method_option :username, :aliases => '-u', :desc => 'Username to login as'
    method_option :sshkey, :aliases => '-k', :desc => 'SSH Key to use', :default => '/tmp/sshkey'
    method_option :tests, :aliases => '-t', :desc => 'Serverspec tests to execute'
    method_option :sub_tests, :aliases => '-s', :desc => 'Specific test from given serverspec file', :default => '\'\''
    method_option :results_file, :aliases => '-r', :desc => 'File to store the results'
    method_option :port, :aliases => '-p', :desc => 'Port to connect on', :default => 22
    def remote(encoded_key)
      spectask = NoradServerspecRunner::Task.new(options[:tests], options[:sub_tests], options[:results_file])

      spectask.host = options[:host]
      spectask.username = options[:username]
      spectask.ssh_port = options[:port]
      # Decode the key and store
      File.open(options[:sshkey], "w") do |f|
        f.write Base64.decode64(encoded_key)
      end
      spectask.sshkey = options[:sshkey]
      spectask.run
    end

    desc 'local', 'Will execute serverspec tests locally'
    long_desc <<-SPEC_LOCAL

    `norad_serverspec_runner local` will run serverspec tests locally
    SPEC_LOCAL
    method_option :tests, :aliases => '-t', :desc => 'Serverspec tests to execute'
    method_option :results_file, :aliases => '-r', :desc => 'File to store the results'
    def local
      spectask = NoradServerspecRunner::Task.new(options[:tests], options[:results_file])
      spectask.run
    end
  end
end
